jupyter_sphinx: Jupyter Sphinx Extension
========================================

Description
-----------

Jupyter Sphinx Extension

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/jupyter-sphinx/

